# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'HostsEntry',
]

@pulumi.output_type
class HostsEntry(dict):
    def __init__(__self__, *,
                 address: str,
                 hostnames: Sequence[str]):
        """
        :param str address: The IP address.
        :param Sequence[str] hostnames: The hostnames.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "hostnames", hostnames)

    @property
    @pulumi.getter
    def address(self) -> str:
        """
        The IP address.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def hostnames(self) -> Sequence[str]:
        """
        The hostnames.
        """
        return pulumi.get(self, "hostnames")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'HostsEntryArgs',
    'ProviderSshArgs',
    'ProviderSshNodeArgs',
]

@pulumi.input_type
class HostsEntryArgs:
    def __init__(__self__, *,
                 address: pulumi.Input[str],
                 hostnames: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        :param pulumi.Input[str] address: The IP address.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] hostnames: The hostnames.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "hostnames", hostnames)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Input[str]:
        """
        The IP address.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: pulumi.Input[str]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter
    def hostnames(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The hostnames.
        """
        return pulumi.get(self, "hostnames")

    @hostnames.setter
    def hostnames(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "hostnames", value)


@pulumi.input_type
class ProviderSshArgs:
    def __init__(__self__, *,
                 agent: Optional[pulumi.Input[bool]] = None,
                 agent_socket: Optional[pulumi.Input[str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['ProviderSshNodeArgs']]]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 socks5_password: Optional[pulumi.Input[str]] = None,
                 socks5_server: Optional[pulumi.Input[str]] = None,
                 socks5_username: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] agent: Whether to use the SSH agent for authentication. Takes precedence over the `private_key` and `password` fields. Defaults to the value of the `PROXMOX_VE_SSH_AGENT` environment variable, or `false` if not set.
        :param pulumi.Input[str] agent_socket: The path to the SSH agent socket. Defaults to the value of the `SSH_AUTH_SOCK` environment variable.
        :param pulumi.Input[Sequence[pulumi.Input['ProviderSshNodeArgs']]] nodes: Overrides for SSH connection configuration for a Proxmox VE node.
        :param pulumi.Input[str] password: The password used for the SSH connection. Defaults to the value of the `password` field of the `provider` block.
        :param pulumi.Input[str] private_key: The unencrypted private key (in PEM format) used for the SSH connection. Defaults to the value of the `PROXMOX_VE_SSH_PRIVATE_KEY` environment variable.
        :param pulumi.Input[str] socks5_password: The password for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_PASSWORD` environment variable.
        :param pulumi.Input[str] socks5_server: The address:port of the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_SERVER` environment variable.
        :param pulumi.Input[str] socks5_username: The username for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_USERNAME` environment variable.
        :param pulumi.Input[str] username: The username used for the SSH connection. Defaults to the value of the `username` field of the `provider` block.
        """
        if agent is not None:
            pulumi.set(__self__, "agent", agent)
        if agent_socket is not None:
            pulumi.set(__self__, "agent_socket", agent_socket)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if socks5_password is not None:
            pulumi.set(__self__, "socks5_password", socks5_password)
        if socks5_server is not None:
            pulumi.set(__self__, "socks5_server", socks5_server)
        if socks5_username is not None:
            pulumi.set(__self__, "socks5_username", socks5_username)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def agent(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use the SSH agent for authentication. Takes precedence over the `private_key` and `password` fields. Defaults to the value of the `PROXMOX_VE_SSH_AGENT` environment variable, or `false` if not set.
        """
        return pulumi.get(self, "agent")

    @agent.setter
    def agent(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "agent", value)

    @property
    @pulumi.getter(name="agentSocket")
    def agent_socket(self) -> Optional[pulumi.Input[str]]:
        """
        The path to the SSH agent socket. Defaults to the value of the `SSH_AUTH_SOCK` environment variable.
        """
        return pulumi.get(self, "agent_socket")

    @agent_socket.setter
    def agent_socket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_socket", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProviderSshNodeArgs']]]]:
        """
        Overrides for SSH connection configuration for a Proxmox VE node.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProviderSshNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password used for the SSH connection. Defaults to the value of the `password` field of the `provider` block.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        """
        The unencrypted private key (in PEM format) used for the SSH connection. Defaults to the value of the `PROXMOX_VE_SSH_PRIVATE_KEY` environment variable.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="socks5Password")
    def socks5_password(self) -> Optional[pulumi.Input[str]]:
        """
        The password for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_PASSWORD` environment variable.
        """
        return pulumi.get(self, "socks5_password")

    @socks5_password.setter
    def socks5_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "socks5_password", value)

    @property
    @pulumi.getter(name="socks5Server")
    def socks5_server(self) -> Optional[pulumi.Input[str]]:
        """
        The address:port of the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_SERVER` environment variable.
        """
        return pulumi.get(self, "socks5_server")

    @socks5_server.setter
    def socks5_server(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "socks5_server", value)

    @property
    @pulumi.getter(name="socks5Username")
    def socks5_username(self) -> Optional[pulumi.Input[str]]:
        """
        The username for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_USERNAME` environment variable.
        """
        return pulumi.get(self, "socks5_username")

    @socks5_username.setter
    def socks5_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "socks5_username", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The username used for the SSH connection. Defaults to the value of the `username` field of the `provider` block.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class ProviderSshNodeArgs:
    def __init__(__self__, *,
                 address: pulumi.Input[str],
                 name: pulumi.Input[str],
                 port: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] address: The address of the Proxmox VE node.
        :param pulumi.Input[str] name: The name of the Proxmox VE node.
        :param pulumi.Input[int] port: The port of the Proxmox VE node.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Input[str]:
        """
        The address of the Proxmox VE node.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: pulumi.Input[str]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the Proxmox VE node.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The port of the Proxmox VE node.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[str],
                 acls: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]]] = None,
                 comment: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[str] group_id: The group identifier.
        :param pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]] acls: The access control list (multiple blocks supported).
        :param pulumi.Input[str] comment: The group comment.
        """
        pulumi.set(__self__, "group_id", group_id)
        if acls is not None:
            pulumi.set(__self__, "acls", acls)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The group identifier.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def acls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]]]:
        """
        The access control list (multiple blocks supported).
        """
        return pulumi.get(self, "acls")

    @acls.setter
    def acls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]]]):
        pulumi.set(self, "acls", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The group comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 acls: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]] acls: The access control list (multiple blocks supported).
        :param pulumi.Input[str] comment: The group comment.
        :param pulumi.Input[str] group_id: The group identifier.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: The group members as a list of `username@realm` entries
        """
        if acls is not None:
            pulumi.set(__self__, "acls", acls)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if members is not None:
            pulumi.set(__self__, "members", members)

    @property
    @pulumi.getter
    def acls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]]]:
        """
        The access control list (multiple blocks supported).
        """
        return pulumi.get(self, "acls")

    @acls.setter
    def acls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAclArgs']]]]):
        pulumi.set(self, "acls", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The group comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The group identifier.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The group members as a list of `username@realm` entries
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "members", value)


class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acls: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GroupAclArgs']]]]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a user group.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        operations_team = proxmoxve.permission.Group("operationsTeam",
            comment="Managed by Terraform",
            group_id="operations-team")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        Instances can be imported using the `group_id`, e.g.,

        bash

        ```sh
        $ pulumi import proxmoxve:Permission/group:Group operations_team operations-team
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GroupAclArgs']]]] acls: The access control list (multiple blocks supported).
        :param pulumi.Input[str] comment: The group comment.
        :param pulumi.Input[str] group_id: The group identifier.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a user group.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        operations_team = proxmoxve.permission.Group("operationsTeam",
            comment="Managed by Terraform",
            group_id="operations-team")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        Instances can be imported using the `group_id`, e.g.,

        bash

        ```sh
        $ pulumi import proxmoxve:Permission/group:Group operations_team operations-team
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acls: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GroupAclArgs']]]]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["acls"] = acls
            __props__.__dict__["comment"] = comment
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["members"] = None
        super(Group, __self__).__init__(
            'proxmoxve:Permission/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acls: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GroupAclArgs']]]]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GroupAclArgs']]]] acls: The access control list (multiple blocks supported).
        :param pulumi.Input[str] comment: The group comment.
        :param pulumi.Input[str] group_id: The group identifier.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: The group members as a list of `username@realm` entries
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["acls"] = acls
        __props__.__dict__["comment"] = comment
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["members"] = members
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def acls(self) -> pulumi.Output[Optional[Sequence['outputs.GroupAcl']]]:
        """
        The access control list (multiple blocks supported).
        """
        return pulumi.get(self, "acls")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        The group comment.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The group identifier.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def members(self) -> pulumi.Output[Sequence[str]]:
        """
        The group members as a list of `username@realm` entries
        """
        return pulumi.get(self, "members")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetUsersResult',
    'AwaitableGetUsersResult',
    'get_users',
    'get_users_output',
]

@pulumi.output_type
class GetUsersResult:
    """
    A collection of values returned by getUsers.
    """
    def __init__(__self__, comments=None, emails=None, enableds=None, expiration_dates=None, first_names=None, groups=None, id=None, keys=None, last_names=None, user_ids=None):
        if comments and not isinstance(comments, list):
            raise TypeError("Expected argument 'comments' to be a list")
        pulumi.set(__self__, "comments", comments)
        if emails and not isinstance(emails, list):
            raise TypeError("Expected argument 'emails' to be a list")
        pulumi.set(__self__, "emails", emails)
        if enableds and not isinstance(enableds, list):
            raise TypeError("Expected argument 'enableds' to be a list")
        pulumi.set(__self__, "enableds", enableds)
        if expiration_dates and not isinstance(expiration_dates, list):
            raise TypeError("Expected argument 'expiration_dates' to be a list")
        pulumi.set(__self__, "expiration_dates", expiration_dates)
        if first_names and not isinstance(first_names, list):
            raise TypeError("Expected argument 'first_names' to be a list")
        pulumi.set(__self__, "first_names", first_names)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keys and not isinstance(keys, list):
            raise TypeError("Expected argument 'keys' to be a list")
        pulumi.set(__self__, "keys", keys)
        if last_names and not isinstance(last_names, list):
            raise TypeError("Expected argument 'last_names' to be a list")
        pulumi.set(__self__, "last_names", last_names)
        if user_ids and not isinstance(user_ids, list):
            raise TypeError("Expected argument 'user_ids' to be a list")
        pulumi.set(__self__, "user_ids", user_ids)

    @property
    @pulumi.getter
    def comments(self) -> Sequence[str]:
        """
        The user comments.
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter
    def emails(self) -> Sequence[str]:
        """
        The users' email addresses.
        """
        return pulumi.get(self, "emails")

    @property
    @pulumi.getter
    def enableds(self) -> Sequence[bool]:
        """
        Whether a user account is enabled.
        """
        return pulumi.get(self, "enableds")

    @property
    @pulumi.getter(name="expirationDates")
    def expiration_dates(self) -> Sequence[str]:
        """
        The user accounts' expiration dates (RFC 3339).
        """
        return pulumi.get(self, "expiration_dates")

    @property
    @pulumi.getter(name="firstNames")
    def first_names(self) -> Sequence[str]:
        """
        The users' first names.
        """
        return pulumi.get(self, "first_names")

    @property
    @pulumi.getter
    def groups(self) -> Sequence[Sequence[str]]:
        """
        The users' groups.
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def keys(self) -> Sequence[str]:
        """
        The users' keys.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter(name="lastNames")
    def last_names(self) -> Sequence[str]:
        """
        The users' last names.
        """
        return pulumi.get(self, "last_names")

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Sequence[str]:
        """
        The user identifiers.
        """
        return pulumi.get(self, "user_ids")


class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            comments=self.comments,
            emails=self.emails,
            enableds=self.enableds,
            expiration_dates=self.expiration_dates,
            first_names=self.first_names,
            groups=self.groups,
            id=self.id,
            keys=self.keys,
            last_names=self.last_names,
            user_ids=self.user_ids)


def get_users(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsersResult:
    """
    Retrieves information about all the available users.

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    available_users = proxmoxve.Permission.get_users()
    ```
    <!--End PulumiCodeChooser -->
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('proxmoxve:Permission/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult).value

    return AwaitableGetUsersResult(
        comments=pulumi.get(__ret__, 'comments'),
        emails=pulumi.get(__ret__, 'emails'),
        enableds=pulumi.get(__ret__, 'enableds'),
        expiration_dates=pulumi.get(__ret__, 'expiration_dates'),
        first_names=pulumi.get(__ret__, 'first_names'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        keys=pulumi.get(__ret__, 'keys'),
        last_names=pulumi.get(__ret__, 'last_names'),
        user_ids=pulumi.get(__ret__, 'user_ids'))


@_utilities.lift_output_func(get_users)
def get_users_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUsersResult]:
    """
    Retrieves information about all the available users.

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    available_users = proxmoxve.Permission.get_users()
    ```
    <!--End PulumiCodeChooser -->
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'Ssh',
    'SshNode',
]

@pulumi.output_type
class Ssh(dict):
    def __init__(__self__, *,
                 agent: Optional[bool] = None,
                 agent_socket: Optional[str] = None,
                 nodes: Optional[Sequence['outputs.SshNode']] = None,
                 password: Optional[str] = None,
                 private_key: Optional[str] = None,
                 socks5_password: Optional[str] = None,
                 socks5_server: Optional[str] = None,
                 socks5_username: Optional[str] = None,
                 username: Optional[str] = None):
        """
        :param bool agent: Whether to use the SSH agent for authentication. Takes precedence over the `private_key` and `password` fields. Defaults to the value of the `PROXMOX_VE_SSH_AGENT` environment variable, or `false` if not set.
        :param str agent_socket: The path to the SSH agent socket. Defaults to the value of the `SSH_AUTH_SOCK` environment variable.
        :param Sequence['SshNodeArgs'] nodes: Overrides for SSH connection configuration for a Proxmox VE node.
        :param str password: The password used for the SSH connection. Defaults to the value of the `password` field of the `provider` block.
        :param str private_key: The unencrypted private key (in PEM format) used for the SSH connection. Defaults to the value of the `PROXMOX_VE_SSH_PRIVATE_KEY` environment variable.
        :param str socks5_password: The password for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_PASSWORD` environment variable.
        :param str socks5_server: The address:port of the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_SERVER` environment variable.
        :param str socks5_username: The username for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_USERNAME` environment variable.
        :param str username: The username used for the SSH connection. Defaults to the value of the `username` field of the `provider` block.
        """
        if agent is not None:
            pulumi.set(__self__, "agent", agent)
        if agent_socket is not None:
            pulumi.set(__self__, "agent_socket", agent_socket)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if socks5_password is not None:
            pulumi.set(__self__, "socks5_password", socks5_password)
        if socks5_server is not None:
            pulumi.set(__self__, "socks5_server", socks5_server)
        if socks5_username is not None:
            pulumi.set(__self__, "socks5_username", socks5_username)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def agent(self) -> Optional[bool]:
        """
        Whether to use the SSH agent for authentication. Takes precedence over the `private_key` and `password` fields. Defaults to the value of the `PROXMOX_VE_SSH_AGENT` environment variable, or `false` if not set.
        """
        return pulumi.get(self, "agent")

    @property
    @pulumi.getter(name="agentSocket")
    def agent_socket(self) -> Optional[str]:
        """
        The path to the SSH agent socket. Defaults to the value of the `SSH_AUTH_SOCK` environment variable.
        """
        return pulumi.get(self, "agent_socket")

    @property
    @pulumi.getter
    def nodes(self) -> Optional[Sequence['outputs.SshNode']]:
        """
        Overrides for SSH connection configuration for a Proxmox VE node.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def password(self) -> Optional[str]:
        """
        The password used for the SSH connection. Defaults to the value of the `password` field of the `provider` block.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[str]:
        """
        The unencrypted private key (in PEM format) used for the SSH connection. Defaults to the value of the `PROXMOX_VE_SSH_PRIVATE_KEY` environment variable.
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="socks5Password")
    def socks5_password(self) -> Optional[str]:
        """
        The password for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_PASSWORD` environment variable.
        """
        return pulumi.get(self, "socks5_password")

    @property
    @pulumi.getter(name="socks5Server")
    def socks5_server(self) -> Optional[str]:
        """
        The address:port of the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_SERVER` environment variable.
        """
        return pulumi.get(self, "socks5_server")

    @property
    @pulumi.getter(name="socks5Username")
    def socks5_username(self) -> Optional[str]:
        """
        The username for the SOCKS5 proxy server. Defaults to the value of the `PROXMOX_VE_SSH_SOCKS5_USERNAME` environment variable.
        """
        return pulumi.get(self, "socks5_username")

    @property
    @pulumi.getter
    def username(self) -> Optional[str]:
        """
        The username used for the SSH connection. Defaults to the value of the `username` field of the `provider` block.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class SshNode(dict):
    def __init__(__self__, *,
                 address: str,
                 name: str,
                 port: Optional[int] = None):
        """
        :param str address: The address of the Proxmox VE node.
        :param str name: The name of the Proxmox VE node.
        :param int port: The port of the Proxmox VE node.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def address(self) -> str:
        """
        The address of the Proxmox VE node.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the Proxmox VE node.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def port(self) -> Optional[int]:
        """
        The port of the Proxmox VE node.
        """
        return pulumi.get(self, "port")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetHAGroupResult',
    'AwaitableGetHAGroupResult',
    'get_ha_group',
    'get_ha_group_output',
]

@pulumi.output_type
class GetHAGroupResult:
    """
    A collection of values returned by getHAGroup.
    """
    def __init__(__self__, comment=None, group=None, id=None, no_failback=None, nodes=None, restricted=None):
        if comment and not isinstance(comment, str):
            raise TypeError("Expected argument 'comment' to be a str")
        pulumi.set(__self__, "comment", comment)
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if no_failback and not isinstance(no_failback, bool):
            raise TypeError("Expected argument 'no_failback' to be a bool")
        pulumi.set(__self__, "no_failback", no_failback)
        if nodes and not isinstance(nodes, dict):
            raise TypeError("Expected argument 'nodes' to be a dict")
        pulumi.set(__self__, "nodes", nodes)
        if restricted and not isinstance(restricted, bool):
            raise TypeError("Expected argument 'restricted' to be a bool")
        pulumi.set(__self__, "restricted", restricted)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        The comment associated with this group
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def group(self) -> str:
        """
        The identifier of the High Availability group to read.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="noFailback")
    def no_failback(self) -> bool:
        """
        A flag that indicates that failing back to a higher priority node is disabled for this HA group.
        """
        return pulumi.get(self, "no_failback")

    @property
    @pulumi.getter
    def nodes(self) -> Mapping[str, int]:
        """
        The member nodes for this group. They are provided as a map, where the keys are the node names and the values represent their priority: integers for known priorities or `null` for unset priorities.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def restricted(self) -> bool:
        """
        A flag that indicates that other nodes may not be used to run resources associated to this HA group.
        """
        return pulumi.get(self, "restricted")


class AwaitableGetHAGroupResult(GetHAGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHAGroupResult(
            comment=self.comment,
            group=self.group,
            id=self.id,
            no_failback=self.no_failback,
            nodes=self.nodes,
            restricted=self.restricted)


def get_ha_group(group: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHAGroupResult:
    """
    Retrieves information about a specific High Availability group.

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    all = proxmoxve.HA.get_ha_groups()
    example = [proxmoxve.HA.get_ha_group(group=__value) for __key, __value in all.group_ids]
    pulumi.export("proxmoxVirtualEnvironmentHagroupsFull", example)
    ```
    <!--End PulumiCodeChooser -->


    :param str group: The identifier of the High Availability group to read.
    """
    __args__ = dict()
    __args__['group'] = group
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('proxmoxve:HA/getHAGroup:getHAGroup', __args__, opts=opts, typ=GetHAGroupResult).value

    return AwaitableGetHAGroupResult(
        comment=pulumi.get(__ret__, 'comment'),
        group=pulumi.get(__ret__, 'group'),
        id=pulumi.get(__ret__, 'id'),
        no_failback=pulumi.get(__ret__, 'no_failback'),
        nodes=pulumi.get(__ret__, 'nodes'),
        restricted=pulumi.get(__ret__, 'restricted'))


@_utilities.lift_output_func(get_ha_group)
def get_ha_group_output(group: Optional[pulumi.Input[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetHAGroupResult]:
    """
    Retrieves information about a specific High Availability group.

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    all = proxmoxve.HA.get_ha_groups()
    example = [proxmoxve.HA.get_ha_group(group=__value) for __key, __value in all.group_ids]
    pulumi.export("proxmoxVirtualEnvironmentHagroupsFull", example)
    ```
    <!--End PulumiCodeChooser -->


    :param str group: The identifier of the High Availability group to read.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['OptionsArgs', 'Options']

@pulumi.input_type
class OptionsArgs:
    def __init__(__self__, *,
                 bandwidth_limit_clone: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_default: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_migration: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_move: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_restore: Optional[pulumi.Input[int]] = None,
                 console: Optional[pulumi.Input[str]] = None,
                 crs_ha: Optional[pulumi.Input[str]] = None,
                 crs_ha_rebalance_on_start: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 email_from: Optional[pulumi.Input[str]] = None,
                 ha_shutdown_policy: Optional[pulumi.Input[str]] = None,
                 http_proxy: Optional[pulumi.Input[str]] = None,
                 keyboard: Optional[pulumi.Input[str]] = None,
                 language: Optional[pulumi.Input[str]] = None,
                 mac_prefix: Optional[pulumi.Input[str]] = None,
                 max_workers: Optional[pulumi.Input[int]] = None,
                 migration_cidr: Optional[pulumi.Input[str]] = None,
                 migration_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Options resource.
        :param pulumi.Input[int] bandwidth_limit_clone: Clone I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_default: Default I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_migration: Migration I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_move: Move I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_restore: Restore I/O bandwidth limit in KiB/s.
        :param pulumi.Input[str] console: Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        :param pulumi.Input[str] crs_ha: Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        :param pulumi.Input[bool] crs_ha_rebalance_on_start: Cluster resource scheduling setting for HA rebalance on start.
        :param pulumi.Input[str] description: Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        :param pulumi.Input[str] email_from: email address to send notification from (default is root@$hostname).
        :param pulumi.Input[str] ha_shutdown_policy: Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        :param pulumi.Input[str] http_proxy: Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        :param pulumi.Input[str] keyboard: Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        :param pulumi.Input[str] language: Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        :param pulumi.Input[str] mac_prefix: Prefix for autogenerated MAC addresses.
        :param pulumi.Input[int] max_workers: Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        :param pulumi.Input[str] migration_cidr: Cluster wide migration network CIDR.
        :param pulumi.Input[str] migration_type: Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        if bandwidth_limit_clone is not None:
            pulumi.set(__self__, "bandwidth_limit_clone", bandwidth_limit_clone)
        if bandwidth_limit_default is not None:
            pulumi.set(__self__, "bandwidth_limit_default", bandwidth_limit_default)
        if bandwidth_limit_migration is not None:
            pulumi.set(__self__, "bandwidth_limit_migration", bandwidth_limit_migration)
        if bandwidth_limit_move is not None:
            pulumi.set(__self__, "bandwidth_limit_move", bandwidth_limit_move)
        if bandwidth_limit_restore is not None:
            pulumi.set(__self__, "bandwidth_limit_restore", bandwidth_limit_restore)
        if console is not None:
            pulumi.set(__self__, "console", console)
        if crs_ha is not None:
            pulumi.set(__self__, "crs_ha", crs_ha)
        if crs_ha_rebalance_on_start is not None:
            pulumi.set(__self__, "crs_ha_rebalance_on_start", crs_ha_rebalance_on_start)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email_from is not None:
            pulumi.set(__self__, "email_from", email_from)
        if ha_shutdown_policy is not None:
            pulumi.set(__self__, "ha_shutdown_policy", ha_shutdown_policy)
        if http_proxy is not None:
            pulumi.set(__self__, "http_proxy", http_proxy)
        if keyboard is not None:
            pulumi.set(__self__, "keyboard", keyboard)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if mac_prefix is not None:
            pulumi.set(__self__, "mac_prefix", mac_prefix)
        if max_workers is not None:
            pulumi.set(__self__, "max_workers", max_workers)
        if migration_cidr is not None:
            pulumi.set(__self__, "migration_cidr", migration_cidr)
        if migration_type is not None:
            pulumi.set(__self__, "migration_type", migration_type)

    @property
    @pulumi.getter(name="bandwidthLimitClone")
    def bandwidth_limit_clone(self) -> Optional[pulumi.Input[int]]:
        """
        Clone I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_clone")

    @bandwidth_limit_clone.setter
    def bandwidth_limit_clone(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_clone", value)

    @property
    @pulumi.getter(name="bandwidthLimitDefault")
    def bandwidth_limit_default(self) -> Optional[pulumi.Input[int]]:
        """
        Default I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_default")

    @bandwidth_limit_default.setter
    def bandwidth_limit_default(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_default", value)

    @property
    @pulumi.getter(name="bandwidthLimitMigration")
    def bandwidth_limit_migration(self) -> Optional[pulumi.Input[int]]:
        """
        Migration I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_migration")

    @bandwidth_limit_migration.setter
    def bandwidth_limit_migration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_migration", value)

    @property
    @pulumi.getter(name="bandwidthLimitMove")
    def bandwidth_limit_move(self) -> Optional[pulumi.Input[int]]:
        """
        Move I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_move")

    @bandwidth_limit_move.setter
    def bandwidth_limit_move(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_move", value)

    @property
    @pulumi.getter(name="bandwidthLimitRestore")
    def bandwidth_limit_restore(self) -> Optional[pulumi.Input[int]]:
        """
        Restore I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_restore")

    @bandwidth_limit_restore.setter
    def bandwidth_limit_restore(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_restore", value)

    @property
    @pulumi.getter
    def console(self) -> Optional[pulumi.Input[str]]:
        """
        Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        """
        return pulumi.get(self, "console")

    @console.setter
    def console(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "console", value)

    @property
    @pulumi.getter(name="crsHa")
    def crs_ha(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        """
        return pulumi.get(self, "crs_ha")

    @crs_ha.setter
    def crs_ha(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "crs_ha", value)

    @property
    @pulumi.getter(name="crsHaRebalanceOnStart")
    def crs_ha_rebalance_on_start(self) -> Optional[pulumi.Input[bool]]:
        """
        Cluster resource scheduling setting for HA rebalance on start.
        """
        return pulumi.get(self, "crs_ha_rebalance_on_start")

    @crs_ha_rebalance_on_start.setter
    def crs_ha_rebalance_on_start(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "crs_ha_rebalance_on_start", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="emailFrom")
    def email_from(self) -> Optional[pulumi.Input[str]]:
        """
        email address to send notification from (default is root@$hostname).
        """
        return pulumi.get(self, "email_from")

    @email_from.setter
    def email_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_from", value)

    @property
    @pulumi.getter(name="haShutdownPolicy")
    def ha_shutdown_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        """
        return pulumi.get(self, "ha_shutdown_policy")

    @ha_shutdown_policy.setter
    def ha_shutdown_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ha_shutdown_policy", value)

    @property
    @pulumi.getter(name="httpProxy")
    def http_proxy(self) -> Optional[pulumi.Input[str]]:
        """
        Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        """
        return pulumi.get(self, "http_proxy")

    @http_proxy.setter
    def http_proxy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "http_proxy", value)

    @property
    @pulumi.getter
    def keyboard(self) -> Optional[pulumi.Input[str]]:
        """
        Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        """
        return pulumi.get(self, "keyboard")

    @keyboard.setter
    def keyboard(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "keyboard", value)

    @property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[str]]:
        """
        Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "language", value)

    @property
    @pulumi.getter(name="macPrefix")
    def mac_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Prefix for autogenerated MAC addresses.
        """
        return pulumi.get(self, "mac_prefix")

    @mac_prefix.setter
    def mac_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_prefix", value)

    @property
    @pulumi.getter(name="maxWorkers")
    def max_workers(self) -> Optional[pulumi.Input[int]]:
        """
        Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        """
        return pulumi.get(self, "max_workers")

    @max_workers.setter
    def max_workers(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_workers", value)

    @property
    @pulumi.getter(name="migrationCidr")
    def migration_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster wide migration network CIDR.
        """
        return pulumi.get(self, "migration_cidr")

    @migration_cidr.setter
    def migration_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "migration_cidr", value)

    @property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        return pulumi.get(self, "migration_type")

    @migration_type.setter
    def migration_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "migration_type", value)


@pulumi.input_type
class _OptionsState:
    def __init__(__self__, *,
                 bandwidth_limit_clone: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_default: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_migration: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_move: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_restore: Optional[pulumi.Input[int]] = None,
                 console: Optional[pulumi.Input[str]] = None,
                 crs_ha: Optional[pulumi.Input[str]] = None,
                 crs_ha_rebalance_on_start: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 email_from: Optional[pulumi.Input[str]] = None,
                 ha_shutdown_policy: Optional[pulumi.Input[str]] = None,
                 http_proxy: Optional[pulumi.Input[str]] = None,
                 keyboard: Optional[pulumi.Input[str]] = None,
                 language: Optional[pulumi.Input[str]] = None,
                 mac_prefix: Optional[pulumi.Input[str]] = None,
                 max_workers: Optional[pulumi.Input[int]] = None,
                 migration_cidr: Optional[pulumi.Input[str]] = None,
                 migration_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Options resources.
        :param pulumi.Input[int] bandwidth_limit_clone: Clone I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_default: Default I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_migration: Migration I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_move: Move I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_restore: Restore I/O bandwidth limit in KiB/s.
        :param pulumi.Input[str] console: Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        :param pulumi.Input[str] crs_ha: Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        :param pulumi.Input[bool] crs_ha_rebalance_on_start: Cluster resource scheduling setting for HA rebalance on start.
        :param pulumi.Input[str] description: Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        :param pulumi.Input[str] email_from: email address to send notification from (default is root@$hostname).
        :param pulumi.Input[str] ha_shutdown_policy: Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        :param pulumi.Input[str] http_proxy: Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        :param pulumi.Input[str] keyboard: Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        :param pulumi.Input[str] language: Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        :param pulumi.Input[str] mac_prefix: Prefix for autogenerated MAC addresses.
        :param pulumi.Input[int] max_workers: Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        :param pulumi.Input[str] migration_cidr: Cluster wide migration network CIDR.
        :param pulumi.Input[str] migration_type: Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        if bandwidth_limit_clone is not None:
            pulumi.set(__self__, "bandwidth_limit_clone", bandwidth_limit_clone)
        if bandwidth_limit_default is not None:
            pulumi.set(__self__, "bandwidth_limit_default", bandwidth_limit_default)
        if bandwidth_limit_migration is not None:
            pulumi.set(__self__, "bandwidth_limit_migration", bandwidth_limit_migration)
        if bandwidth_limit_move is not None:
            pulumi.set(__self__, "bandwidth_limit_move", bandwidth_limit_move)
        if bandwidth_limit_restore is not None:
            pulumi.set(__self__, "bandwidth_limit_restore", bandwidth_limit_restore)
        if console is not None:
            pulumi.set(__self__, "console", console)
        if crs_ha is not None:
            pulumi.set(__self__, "crs_ha", crs_ha)
        if crs_ha_rebalance_on_start is not None:
            pulumi.set(__self__, "crs_ha_rebalance_on_start", crs_ha_rebalance_on_start)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email_from is not None:
            pulumi.set(__self__, "email_from", email_from)
        if ha_shutdown_policy is not None:
            pulumi.set(__self__, "ha_shutdown_policy", ha_shutdown_policy)
        if http_proxy is not None:
            pulumi.set(__self__, "http_proxy", http_proxy)
        if keyboard is not None:
            pulumi.set(__self__, "keyboard", keyboard)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if mac_prefix is not None:
            pulumi.set(__self__, "mac_prefix", mac_prefix)
        if max_workers is not None:
            pulumi.set(__self__, "max_workers", max_workers)
        if migration_cidr is not None:
            pulumi.set(__self__, "migration_cidr", migration_cidr)
        if migration_type is not None:
            pulumi.set(__self__, "migration_type", migration_type)

    @property
    @pulumi.getter(name="bandwidthLimitClone")
    def bandwidth_limit_clone(self) -> Optional[pulumi.Input[int]]:
        """
        Clone I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_clone")

    @bandwidth_limit_clone.setter
    def bandwidth_limit_clone(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_clone", value)

    @property
    @pulumi.getter(name="bandwidthLimitDefault")
    def bandwidth_limit_default(self) -> Optional[pulumi.Input[int]]:
        """
        Default I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_default")

    @bandwidth_limit_default.setter
    def bandwidth_limit_default(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_default", value)

    @property
    @pulumi.getter(name="bandwidthLimitMigration")
    def bandwidth_limit_migration(self) -> Optional[pulumi.Input[int]]:
        """
        Migration I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_migration")

    @bandwidth_limit_migration.setter
    def bandwidth_limit_migration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_migration", value)

    @property
    @pulumi.getter(name="bandwidthLimitMove")
    def bandwidth_limit_move(self) -> Optional[pulumi.Input[int]]:
        """
        Move I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_move")

    @bandwidth_limit_move.setter
    def bandwidth_limit_move(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_move", value)

    @property
    @pulumi.getter(name="bandwidthLimitRestore")
    def bandwidth_limit_restore(self) -> Optional[pulumi.Input[int]]:
        """
        Restore I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_restore")

    @bandwidth_limit_restore.setter
    def bandwidth_limit_restore(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth_limit_restore", value)

    @property
    @pulumi.getter
    def console(self) -> Optional[pulumi.Input[str]]:
        """
        Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        """
        return pulumi.get(self, "console")

    @console.setter
    def console(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "console", value)

    @property
    @pulumi.getter(name="crsHa")
    def crs_ha(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        """
        return pulumi.get(self, "crs_ha")

    @crs_ha.setter
    def crs_ha(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "crs_ha", value)

    @property
    @pulumi.getter(name="crsHaRebalanceOnStart")
    def crs_ha_rebalance_on_start(self) -> Optional[pulumi.Input[bool]]:
        """
        Cluster resource scheduling setting for HA rebalance on start.
        """
        return pulumi.get(self, "crs_ha_rebalance_on_start")

    @crs_ha_rebalance_on_start.setter
    def crs_ha_rebalance_on_start(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "crs_ha_rebalance_on_start", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="emailFrom")
    def email_from(self) -> Optional[pulumi.Input[str]]:
        """
        email address to send notification from (default is root@$hostname).
        """
        return pulumi.get(self, "email_from")

    @email_from.setter
    def email_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_from", value)

    @property
    @pulumi.getter(name="haShutdownPolicy")
    def ha_shutdown_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        """
        return pulumi.get(self, "ha_shutdown_policy")

    @ha_shutdown_policy.setter
    def ha_shutdown_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ha_shutdown_policy", value)

    @property
    @pulumi.getter(name="httpProxy")
    def http_proxy(self) -> Optional[pulumi.Input[str]]:
        """
        Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        """
        return pulumi.get(self, "http_proxy")

    @http_proxy.setter
    def http_proxy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "http_proxy", value)

    @property
    @pulumi.getter
    def keyboard(self) -> Optional[pulumi.Input[str]]:
        """
        Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        """
        return pulumi.get(self, "keyboard")

    @keyboard.setter
    def keyboard(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "keyboard", value)

    @property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[str]]:
        """
        Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "language", value)

    @property
    @pulumi.getter(name="macPrefix")
    def mac_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Prefix for autogenerated MAC addresses.
        """
        return pulumi.get(self, "mac_prefix")

    @mac_prefix.setter
    def mac_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_prefix", value)

    @property
    @pulumi.getter(name="maxWorkers")
    def max_workers(self) -> Optional[pulumi.Input[int]]:
        """
        Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        """
        return pulumi.get(self, "max_workers")

    @max_workers.setter
    def max_workers(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_workers", value)

    @property
    @pulumi.getter(name="migrationCidr")
    def migration_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster wide migration network CIDR.
        """
        return pulumi.get(self, "migration_cidr")

    @migration_cidr.setter
    def migration_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "migration_cidr", value)

    @property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> Optional[pulumi.Input[str]]:
        """
        Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        return pulumi.get(self, "migration_type")

    @migration_type.setter
    def migration_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "migration_type", value)


class Options(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth_limit_clone: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_default: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_migration: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_move: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_restore: Optional[pulumi.Input[int]] = None,
                 console: Optional[pulumi.Input[str]] = None,
                 crs_ha: Optional[pulumi.Input[str]] = None,
                 crs_ha_rebalance_on_start: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 email_from: Optional[pulumi.Input[str]] = None,
                 ha_shutdown_policy: Optional[pulumi.Input[str]] = None,
                 http_proxy: Optional[pulumi.Input[str]] = None,
                 keyboard: Optional[pulumi.Input[str]] = None,
                 language: Optional[pulumi.Input[str]] = None,
                 mac_prefix: Optional[pulumi.Input[str]] = None,
                 max_workers: Optional[pulumi.Input[int]] = None,
                 migration_cidr: Optional[pulumi.Input[str]] = None,
                 migration_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages Proxmox VE Cluster Datacenter options.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        options = proxmoxve.cluster.Options("options",
            bandwidth_limit_default=666666,
            bandwidth_limit_migration=555555,
            email_from="ged@gont.earthsea",
            keyboard="pl",
            language="en",
            max_workers=5,
            migration_cidr="10.0.0.0/8",
            migration_type="secure")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        #!/usr/bin/env sh

        Cluster options are global and can be imported using e.g.:

        ```sh
        $ pulumi import proxmoxve:Cluster/options:Options options cluster
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth_limit_clone: Clone I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_default: Default I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_migration: Migration I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_move: Move I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_restore: Restore I/O bandwidth limit in KiB/s.
        :param pulumi.Input[str] console: Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        :param pulumi.Input[str] crs_ha: Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        :param pulumi.Input[bool] crs_ha_rebalance_on_start: Cluster resource scheduling setting for HA rebalance on start.
        :param pulumi.Input[str] description: Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        :param pulumi.Input[str] email_from: email address to send notification from (default is root@$hostname).
        :param pulumi.Input[str] ha_shutdown_policy: Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        :param pulumi.Input[str] http_proxy: Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        :param pulumi.Input[str] keyboard: Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        :param pulumi.Input[str] language: Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        :param pulumi.Input[str] mac_prefix: Prefix for autogenerated MAC addresses.
        :param pulumi.Input[int] max_workers: Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        :param pulumi.Input[str] migration_cidr: Cluster wide migration network CIDR.
        :param pulumi.Input[str] migration_type: Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[OptionsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Proxmox VE Cluster Datacenter options.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        options = proxmoxve.cluster.Options("options",
            bandwidth_limit_default=666666,
            bandwidth_limit_migration=555555,
            email_from="ged@gont.earthsea",
            keyboard="pl",
            language="en",
            max_workers=5,
            migration_cidr="10.0.0.0/8",
            migration_type="secure")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        #!/usr/bin/env sh

        Cluster options are global and can be imported using e.g.:

        ```sh
        $ pulumi import proxmoxve:Cluster/options:Options options cluster
        ```

        :param str resource_name: The name of the resource.
        :param OptionsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OptionsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth_limit_clone: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_default: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_migration: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_move: Optional[pulumi.Input[int]] = None,
                 bandwidth_limit_restore: Optional[pulumi.Input[int]] = None,
                 console: Optional[pulumi.Input[str]] = None,
                 crs_ha: Optional[pulumi.Input[str]] = None,
                 crs_ha_rebalance_on_start: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 email_from: Optional[pulumi.Input[str]] = None,
                 ha_shutdown_policy: Optional[pulumi.Input[str]] = None,
                 http_proxy: Optional[pulumi.Input[str]] = None,
                 keyboard: Optional[pulumi.Input[str]] = None,
                 language: Optional[pulumi.Input[str]] = None,
                 mac_prefix: Optional[pulumi.Input[str]] = None,
                 max_workers: Optional[pulumi.Input[int]] = None,
                 migration_cidr: Optional[pulumi.Input[str]] = None,
                 migration_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OptionsArgs.__new__(OptionsArgs)

            __props__.__dict__["bandwidth_limit_clone"] = bandwidth_limit_clone
            __props__.__dict__["bandwidth_limit_default"] = bandwidth_limit_default
            __props__.__dict__["bandwidth_limit_migration"] = bandwidth_limit_migration
            __props__.__dict__["bandwidth_limit_move"] = bandwidth_limit_move
            __props__.__dict__["bandwidth_limit_restore"] = bandwidth_limit_restore
            __props__.__dict__["console"] = console
            __props__.__dict__["crs_ha"] = crs_ha
            __props__.__dict__["crs_ha_rebalance_on_start"] = crs_ha_rebalance_on_start
            __props__.__dict__["description"] = description
            __props__.__dict__["email_from"] = email_from
            __props__.__dict__["ha_shutdown_policy"] = ha_shutdown_policy
            __props__.__dict__["http_proxy"] = http_proxy
            __props__.__dict__["keyboard"] = keyboard
            __props__.__dict__["language"] = language
            __props__.__dict__["mac_prefix"] = mac_prefix
            __props__.__dict__["max_workers"] = max_workers
            __props__.__dict__["migration_cidr"] = migration_cidr
            __props__.__dict__["migration_type"] = migration_type
        super(Options, __self__).__init__(
            'proxmoxve:Cluster/options:Options',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth_limit_clone: Optional[pulumi.Input[int]] = None,
            bandwidth_limit_default: Optional[pulumi.Input[int]] = None,
            bandwidth_limit_migration: Optional[pulumi.Input[int]] = None,
            bandwidth_limit_move: Optional[pulumi.Input[int]] = None,
            bandwidth_limit_restore: Optional[pulumi.Input[int]] = None,
            console: Optional[pulumi.Input[str]] = None,
            crs_ha: Optional[pulumi.Input[str]] = None,
            crs_ha_rebalance_on_start: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            email_from: Optional[pulumi.Input[str]] = None,
            ha_shutdown_policy: Optional[pulumi.Input[str]] = None,
            http_proxy: Optional[pulumi.Input[str]] = None,
            keyboard: Optional[pulumi.Input[str]] = None,
            language: Optional[pulumi.Input[str]] = None,
            mac_prefix: Optional[pulumi.Input[str]] = None,
            max_workers: Optional[pulumi.Input[int]] = None,
            migration_cidr: Optional[pulumi.Input[str]] = None,
            migration_type: Optional[pulumi.Input[str]] = None) -> 'Options':
        """
        Get an existing Options resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth_limit_clone: Clone I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_default: Default I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_migration: Migration I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_move: Move I/O bandwidth limit in KiB/s.
        :param pulumi.Input[int] bandwidth_limit_restore: Restore I/O bandwidth limit in KiB/s.
        :param pulumi.Input[str] console: Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        :param pulumi.Input[str] crs_ha: Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        :param pulumi.Input[bool] crs_ha_rebalance_on_start: Cluster resource scheduling setting for HA rebalance on start.
        :param pulumi.Input[str] description: Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        :param pulumi.Input[str] email_from: email address to send notification from (default is root@$hostname).
        :param pulumi.Input[str] ha_shutdown_policy: Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        :param pulumi.Input[str] http_proxy: Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        :param pulumi.Input[str] keyboard: Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        :param pulumi.Input[str] language: Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        :param pulumi.Input[str] mac_prefix: Prefix for autogenerated MAC addresses.
        :param pulumi.Input[int] max_workers: Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        :param pulumi.Input[str] migration_cidr: Cluster wide migration network CIDR.
        :param pulumi.Input[str] migration_type: Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OptionsState.__new__(_OptionsState)

        __props__.__dict__["bandwidth_limit_clone"] = bandwidth_limit_clone
        __props__.__dict__["bandwidth_limit_default"] = bandwidth_limit_default
        __props__.__dict__["bandwidth_limit_migration"] = bandwidth_limit_migration
        __props__.__dict__["bandwidth_limit_move"] = bandwidth_limit_move
        __props__.__dict__["bandwidth_limit_restore"] = bandwidth_limit_restore
        __props__.__dict__["console"] = console
        __props__.__dict__["crs_ha"] = crs_ha
        __props__.__dict__["crs_ha_rebalance_on_start"] = crs_ha_rebalance_on_start
        __props__.__dict__["description"] = description
        __props__.__dict__["email_from"] = email_from
        __props__.__dict__["ha_shutdown_policy"] = ha_shutdown_policy
        __props__.__dict__["http_proxy"] = http_proxy
        __props__.__dict__["keyboard"] = keyboard
        __props__.__dict__["language"] = language
        __props__.__dict__["mac_prefix"] = mac_prefix
        __props__.__dict__["max_workers"] = max_workers
        __props__.__dict__["migration_cidr"] = migration_cidr
        __props__.__dict__["migration_type"] = migration_type
        return Options(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bandwidthLimitClone")
    def bandwidth_limit_clone(self) -> pulumi.Output[Optional[int]]:
        """
        Clone I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_clone")

    @property
    @pulumi.getter(name="bandwidthLimitDefault")
    def bandwidth_limit_default(self) -> pulumi.Output[Optional[int]]:
        """
        Default I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_default")

    @property
    @pulumi.getter(name="bandwidthLimitMigration")
    def bandwidth_limit_migration(self) -> pulumi.Output[Optional[int]]:
        """
        Migration I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_migration")

    @property
    @pulumi.getter(name="bandwidthLimitMove")
    def bandwidth_limit_move(self) -> pulumi.Output[Optional[int]]:
        """
        Move I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_move")

    @property
    @pulumi.getter(name="bandwidthLimitRestore")
    def bandwidth_limit_restore(self) -> pulumi.Output[Optional[int]]:
        """
        Restore I/O bandwidth limit in KiB/s.
        """
        return pulumi.get(self, "bandwidth_limit_restore")

    @property
    @pulumi.getter
    def console(self) -> pulumi.Output[Optional[str]]:
        """
        Select the default Console viewer. Must be `applet` | `vv`| `html5` | `xtermjs`. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer compatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.
        """
        return pulumi.get(self, "console")

    @property
    @pulumi.getter(name="crsHa")
    def crs_ha(self) -> pulumi.Output[str]:
        """
        Cluster resource scheduling setting for HA. Must be `static` | `basic` (default is `basic`).
        """
        return pulumi.get(self, "crs_ha")

    @property
    @pulumi.getter(name="crsHaRebalanceOnStart")
    def crs_ha_rebalance_on_start(self) -> pulumi.Output[Optional[bool]]:
        """
        Cluster resource scheduling setting for HA rebalance on start.
        """
        return pulumi.get(self, "crs_ha_rebalance_on_start")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="emailFrom")
    def email_from(self) -> pulumi.Output[Optional[str]]:
        """
        email address to send notification from (default is root@$hostname).
        """
        return pulumi.get(self, "email_from")

    @property
    @pulumi.getter(name="haShutdownPolicy")
    def ha_shutdown_policy(self) -> pulumi.Output[Optional[str]]:
        """
        Cluster wide HA shutdown policy (). Must be `freeze` | `failover` | `migrate` | `conditional` (default is `conditional`).
        """
        return pulumi.get(self, "ha_shutdown_policy")

    @property
    @pulumi.getter(name="httpProxy")
    def http_proxy(self) -> pulumi.Output[Optional[str]]:
        """
        Specify external http proxy which is used for downloads (example: `http://username:password@host:port/`).
        """
        return pulumi.get(self, "http_proxy")

    @property
    @pulumi.getter
    def keyboard(self) -> pulumi.Output[Optional[str]]:
        """
        Default keyboard layout for vnc server. Must be `de` | `de-ch` | `da` | `en-gb` | `en-us` | `es` | `fi` | `fr` | `fr-be` | `fr-ca` | `fr-ch` | `hu` | `is` | `it` | `ja` | `lt` | `mk` | `nl` | `no` | `pl` | `pt` | `pt-br` | `sv` | `sl` | `tr`.
        """
        return pulumi.get(self, "keyboard")

    @property
    @pulumi.getter
    def language(self) -> pulumi.Output[Optional[str]]:
        """
        Default GUI language. Must be `ca` | `da` | `de` | `en` | `es` | `eu` | `fa` | `fr` | `he` | `it` | `ja` | `nb` | `nn` | `pl` | `pt_BR` | `ru` | `sl` | `sv` | `tr` | `zh_CN` | `zh_TW`.
        """
        return pulumi.get(self, "language")

    @property
    @pulumi.getter(name="macPrefix")
    def mac_prefix(self) -> pulumi.Output[str]:
        """
        Prefix for autogenerated MAC addresses.
        """
        return pulumi.get(self, "mac_prefix")

    @property
    @pulumi.getter(name="maxWorkers")
    def max_workers(self) -> pulumi.Output[Optional[int]]:
        """
        Defines how many workers (per node) are maximal started on actions like 'stopall VMs' or task from the ha-manager.
        """
        return pulumi.get(self, "max_workers")

    @property
    @pulumi.getter(name="migrationCidr")
    def migration_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        Cluster wide migration network CIDR.
        """
        return pulumi.get(self, "migration_cidr")

    @property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> pulumi.Output[Optional[str]]:
        """
        Cluster wide migration type. Must be `secure` | `unsecure` (default is `secure`).
        """
        return pulumi.get(self, "migration_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PoolArgs', 'Pool']

@pulumi.input_type
class PoolArgs:
    def __init__(__self__, *,
                 pool_id: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Pool resource.
        :param pulumi.Input[str] pool_id: The pool identifier.
        :param pulumi.Input[str] comment: The pool comment.
        """
        pulumi.set(__self__, "pool_id", pool_id)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Input[str]:
        """
        The pool identifier.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "pool_id", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The pool comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)


@pulumi.input_type
class _PoolState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['PoolMemberArgs']]]] = None,
                 pool_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Pool resources.
        :param pulumi.Input[str] comment: The pool comment.
        :param pulumi.Input[Sequence[pulumi.Input['PoolMemberArgs']]] members: The pool members.
        :param pulumi.Input[str] pool_id: The pool identifier.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if members is not None:
            pulumi.set(__self__, "members", members)
        if pool_id is not None:
            pulumi.set(__self__, "pool_id", pool_id)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The pool comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PoolMemberArgs']]]]:
        """
        The pool members.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PoolMemberArgs']]]]):
        pulumi.set(self, "members", value)

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[pulumi.Input[str]]:
        """
        The pool identifier.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pool_id", value)


class Pool(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 pool_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a resource pool.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        operations_pool = proxmoxve.permission.Pool("operationsPool",
            comment="Managed by Terraform",
            pool_id="operations-pool")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        Instances can be imported using the `pool_id`, e.g.,

        bash

        ```sh
        $ pulumi import proxmoxve:Permission/pool:Pool operations_pool operations-pool
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: The pool comment.
        :param pulumi.Input[str] pool_id: The pool identifier.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PoolArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a resource pool.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        operations_pool = proxmoxve.permission.Pool("operationsPool",
            comment="Managed by Terraform",
            pool_id="operations-pool")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        Instances can be imported using the `pool_id`, e.g.,

        bash

        ```sh
        $ pulumi import proxmoxve:Permission/pool:Pool operations_pool operations-pool
        ```

        :param str resource_name: The name of the resource.
        :param PoolArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PoolArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 pool_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PoolArgs.__new__(PoolArgs)

            __props__.__dict__["comment"] = comment
            if pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'pool_id'")
            __props__.__dict__["pool_id"] = pool_id
            __props__.__dict__["members"] = None
        super(Pool, __self__).__init__(
            'proxmoxve:Permission/pool:Pool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[str]] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PoolMemberArgs']]]]] = None,
            pool_id: Optional[pulumi.Input[str]] = None) -> 'Pool':
        """
        Get an existing Pool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: The pool comment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PoolMemberArgs']]]] members: The pool members.
        :param pulumi.Input[str] pool_id: The pool identifier.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PoolState.__new__(_PoolState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["members"] = members
        __props__.__dict__["pool_id"] = pool_id
        return Pool(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        The pool comment.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def members(self) -> pulumi.Output[Sequence['outputs.PoolMember']]:
        """
        The pool members.
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Output[str]:
        """
        The pool identifier.
        """
        return pulumi.get(self, "pool_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FirewallSecurityGroupArgs', 'FirewallSecurityGroup']

@pulumi.input_type
class FirewallSecurityGroupArgs:
    def __init__(__self__, *,
                 rules: pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]],
                 comment: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_name: Optional[pulumi.Input[str]] = None,
                 vm_id: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a FirewallSecurityGroup resource.
        :param pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]] rules: Firewall rule block (multiple blocks supported).
        :param pulumi.Input[str] comment: Rule comment.
        :param pulumi.Input[int] container_id: The ID of the container to manage the firewall for.
        :param pulumi.Input[str] name: Security group name.
        :param pulumi.Input[str] node_name: The name of the node.
        :param pulumi.Input[int] vm_id: The ID of the VM to manage the firewall for.
        """
        pulumi.set(__self__, "rules", rules)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if container_id is not None:
            pulumi.set(__self__, "container_id", container_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_name is not None:
            pulumi.set(__self__, "node_name", node_name)
        if vm_id is not None:
            pulumi.set(__self__, "vm_id", vm_id)

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]]:
        """
        Firewall rule block (multiple blocks supported).
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]]):
        pulumi.set(self, "rules", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Rule comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="containerId")
    def container_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the container to manage the firewall for.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "container_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Security group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeName")
    def node_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the node.
        """
        return pulumi.get(self, "node_name")

    @node_name.setter
    def node_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_name", value)

    @property
    @pulumi.getter(name="vmId")
    def vm_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the VM to manage the firewall for.
        """
        return pulumi.get(self, "vm_id")

    @vm_id.setter
    def vm_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vm_id", value)


@pulumi.input_type
class _FirewallSecurityGroupState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_name: Optional[pulumi.Input[str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]]] = None,
                 vm_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering FirewallSecurityGroup resources.
        :param pulumi.Input[str] comment: Rule comment.
        :param pulumi.Input[int] container_id: The ID of the container to manage the firewall for.
        :param pulumi.Input[str] name: Security group name.
        :param pulumi.Input[str] node_name: The name of the node.
        :param pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]] rules: Firewall rule block (multiple blocks supported).
        :param pulumi.Input[int] vm_id: The ID of the VM to manage the firewall for.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if container_id is not None:
            pulumi.set(__self__, "container_id", container_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_name is not None:
            pulumi.set(__self__, "node_name", node_name)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)
        if vm_id is not None:
            pulumi.set(__self__, "vm_id", vm_id)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Rule comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="containerId")
    def container_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the container to manage the firewall for.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "container_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Security group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeName")
    def node_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the node.
        """
        return pulumi.get(self, "node_name")

    @node_name.setter
    def node_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_name", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]]]:
        """
        Firewall rule block (multiple blocks supported).
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FirewallSecurityGroupRuleArgs']]]]):
        pulumi.set(self, "rules", value)

    @property
    @pulumi.getter(name="vmId")
    def vm_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the VM to manage the firewall for.
        """
        return pulumi.get(self, "vm_id")

    @vm_id.setter
    def vm_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vm_id", value)


class FirewallSecurityGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_name: Optional[pulumi.Input[str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['FirewallSecurityGroupRuleArgs']]]]] = None,
                 vm_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        A security group is a collection of rules, defined at cluster level, which can
        be used in all VMs' rules. For example, you can define a group named “webserver”
        with rules to open the http and https ports.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        webserver = proxmoxve.network.FirewallSecurityGroup("webserver",
            comment="Managed by Terraform",
            rules=[
                proxmoxve.network.FirewallSecurityGroupRuleArgs(
                    action="ACCEPT",
                    comment="Allow HTTP",
                    dest="192.168.1.5",
                    dport="80",
                    log="info",
                    proto="tcp",
                    type="in",
                ),
                proxmoxve.network.FirewallSecurityGroupRuleArgs(
                    action="ACCEPT",
                    comment="Allow HTTPS",
                    dest="192.168.1.5",
                    dport="443",
                    log="info",
                    proto="tcp",
                    type="in",
                ),
            ])
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        Instances can be imported using the `name`, e.g.,

        bash

        ```sh
        $ pulumi import proxmoxve:Network/firewallSecurityGroup:FirewallSecurityGroup webserver webserver
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Rule comment.
        :param pulumi.Input[int] container_id: The ID of the container to manage the firewall for.
        :param pulumi.Input[str] name: Security group name.
        :param pulumi.Input[str] node_name: The name of the node.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['FirewallSecurityGroupRuleArgs']]]] rules: Firewall rule block (multiple blocks supported).
        :param pulumi.Input[int] vm_id: The ID of the VM to manage the firewall for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FirewallSecurityGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A security group is a collection of rules, defined at cluster level, which can
        be used in all VMs' rules. For example, you can define a group named “webserver”
        with rules to open the http and https ports.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        webserver = proxmoxve.network.FirewallSecurityGroup("webserver",
            comment="Managed by Terraform",
            rules=[
                proxmoxve.network.FirewallSecurityGroupRuleArgs(
                    action="ACCEPT",
                    comment="Allow HTTP",
                    dest="192.168.1.5",
                    dport="80",
                    log="info",
                    proto="tcp",
                    type="in",
                ),
                proxmoxve.network.FirewallSecurityGroupRuleArgs(
                    action="ACCEPT",
                    comment="Allow HTTPS",
                    dest="192.168.1.5",
                    dport="443",
                    log="info",
                    proto="tcp",
                    type="in",
                ),
            ])
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        Instances can be imported using the `name`, e.g.,

        bash

        ```sh
        $ pulumi import proxmoxve:Network/firewallSecurityGroup:FirewallSecurityGroup webserver webserver
        ```

        :param str resource_name: The name of the resource.
        :param FirewallSecurityGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FirewallSecurityGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_name: Optional[pulumi.Input[str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['FirewallSecurityGroupRuleArgs']]]]] = None,
                 vm_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FirewallSecurityGroupArgs.__new__(FirewallSecurityGroupArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["container_id"] = container_id
            __props__.__dict__["name"] = name
            __props__.__dict__["node_name"] = node_name
            if rules is None and not opts.urn:
                raise TypeError("Missing required property 'rules'")
            __props__.__dict__["rules"] = rules
            __props__.__dict__["vm_id"] = vm_id
        super(FirewallSecurityGroup, __self__).__init__(
            'proxmoxve:Network/firewallSecurityGroup:FirewallSecurityGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[str]] = None,
            container_id: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            node_name: Optional[pulumi.Input[str]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['FirewallSecurityGroupRuleArgs']]]]] = None,
            vm_id: Optional[pulumi.Input[int]] = None) -> 'FirewallSecurityGroup':
        """
        Get an existing FirewallSecurityGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Rule comment.
        :param pulumi.Input[int] container_id: The ID of the container to manage the firewall for.
        :param pulumi.Input[str] name: Security group name.
        :param pulumi.Input[str] node_name: The name of the node.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['FirewallSecurityGroupRuleArgs']]]] rules: Firewall rule block (multiple blocks supported).
        :param pulumi.Input[int] vm_id: The ID of the VM to manage the firewall for.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FirewallSecurityGroupState.__new__(_FirewallSecurityGroupState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["container_id"] = container_id
        __props__.__dict__["name"] = name
        __props__.__dict__["node_name"] = node_name
        __props__.__dict__["rules"] = rules
        __props__.__dict__["vm_id"] = vm_id
        return FirewallSecurityGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        Rule comment.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the container to manage the firewall for.
        """
        return pulumi.get(self, "container_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Security group name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeName")
    def node_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the node.
        """
        return pulumi.get(self, "node_name")

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Sequence['outputs.FirewallSecurityGroupRule']]:
        """
        Firewall rule block (multiple blocks supported).
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter(name="vmId")
    def vm_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the VM to manage the firewall for.
        """
        return pulumi.get(self, "vm_id")

